==> react-build-cli-0.0.25.tgz: package/src/getPlugins.ts <==
import path from 'path';
import fs from 'fs';
import webpack, { DefinePlugin } from 'webpack';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import MiniCssExtractPlugin from 'mini-css-extract-plugin';
import CopyWebpackPlugin from 'copy-webpack-plugin';
import ForkTsCheckerWebpackPlugin from 'fork-ts-checker-webpack-plugin';
import {RcbConfig} from './getConfig';
import utils from './utils';

function hasTSConfig() {
    return fs.existsSync(path.resolve(process.cwd(), 'tsconfig.json'));
}

function addPlugins(basePlugins: webpack.ResolvePlugin[], plugins?: webpack.ResolvePlugin[]) {
    if (plugins) {
        plugins.forEach(function (plugin: HtmlWebpackPlugin | DefinePlugin) {
            basePlugins.push(plugin);
        });
    }

    return basePlugins;
}

export default function getPlugins(rcb: RcbConfig) {
    let htmlWebpackPluginConfig;
    if (rcb.webpackPluginConfig) {
        htmlWebpackPluginConfig = rcb.webpackPluginConfig;
    }
    else {
        htmlWebpackPluginConfig = {
            template: path.resolve('./public/index.html')
        }
    }
    const basePlugins: webpack.ResolvePlugin[] = [
        new CopyWebpackPlugin({
            patterns: [{
                from: path.resolve('public'),
                globOptions: {ignore: ['**/index.html']}
            }]
        }),
        new HtmlWebpackPlugin(htmlWebpackPluginConfig),
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify(utils.getEnv())
            }
        })
    ];

    if (hasTSConfig()) {
        basePlugins.push(new ForkTsCheckerWebpackPlugin({
            async: true
        }));
    }

    if (utils.isDev()) {
        addPlugins(basePlugins, [
            new webpack.HotModuleReplacementPlugin(),
            new MiniCssExtractPlugin({
                filename: 'css/[name].css'
            })
        ]);
    }

    if (utils.isProduction()) {
        addPlugins(basePlugins, [
            new MiniCssExtractPlugin({
                filename: 'css/[name].[hash:8].css'
            })
        ]);
    }

    return basePlugins;
};

==> react-build-cli-0.1.0.tgz: package/src/getPlugins.ts <==
import path from 'path';
import fs from 'fs';
import webpack, { DefinePlugin } from 'webpack';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import MiniCssExtractPlugin from 'mini-css-extract-plugin';
import CopyWebpackPlugin from 'copy-webpack-plugin';
import ForkTsCheckerWebpackPlugin from 'fork-ts-checker-webpack-plugin';
import ESLintPlugin from 'eslint-webpack-plugin';
import { RcbConfig } from './getConfig';
import utils from './utils';

function hasTSConfig() {
    return fs.existsSync(path.resolve(process.cwd(), 'tsconfig.json'));
}

function addPlugins(basePlugins: any, plugins?: any) {
    if (plugins) {
        plugins.forEach(function (plugin: HtmlWebpackPlugin | DefinePlugin) {
            basePlugins.push(plugin);
        });
    }

    return basePlugins;
}

export default function getPlugins(rcb: RcbConfig) {
    const basePlugins: any = [
        new CopyWebpackPlugin({
            patterns: [{
                from: path.resolve('public'),
                globOptions: { ignore: ['**/index.html'] }
            }]
        }),
        new HtmlWebpackPlugin({
            template: path.resolve('./public/index.html')
        }),
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify(utils.getEnv())
            }
        }),
        new ESLintPlugin({
            eslintPath: require.resolve('eslint'),
            resolvePluginsRelativeTo: __dirname,
            baseConfig: utils.requireModule(require.resolve('./eslintrc'))
        })
    ];

    if (hasTSConfig()) {
        basePlugins.push(new ForkTsCheckerWebpackPlugin({
            async: true
        }));
    }

    if (utils.isDev()) {
        addPlugins(basePlugins, [
            new webpack.HotModuleReplacementPlugin(),
            new MiniCssExtractPlugin({
                filename: 'css/[name].css'
            })
        ]);
    }

    if (utils.isProduction()) {
        addPlugins(basePlugins, [
            new MiniCssExtractPlugin({
                filename: 'css/[name].[contenthash:8].css'
            })
        ]);
    }

    if (rcb.webpackPluginConfig && rcb.webpackPluginConfig.length > 0) {
        return [basePlugins, ...rcb.webpackPluginConfig];
    }

    return basePlugins;
};
